package controller

import (
	"electricity_bill_calc/response"
	"electricity_bill_calc/service"
	"net/http"

	"github.com/gin-gonic/gin"
)

type _RegionController struct {
	Router *gin.Engine
}

var RegionController *_RegionController

func InitializeRegionController(router *gin.Engine) {
	RegionController = &_RegionController{
		Router: router,
	}

	RegionController.Router.GET("/region/:rid", fetchRegions)
	RegionController.Router.GET("/regions/:rid", fetchAllLeveledRegions)
}

func fetchRegions(c *gin.Context) {
	result := response.NewResult(c)
	requestParentId := c.Param("rid")
	regions, err := service.RegionService.FetchSubRegions(requestParentId)
	if err != nil {
		result.Error(http.StatusInternalServerError, err.Error())
		return
	}
	if len(regions) == 0 {
		result.Json(http.StatusNotFound, "未能获取到相关的行政区划。", gin.H{"regions": make([]string, 0)})
		return
	}
	result.Json(http.StatusOK, "已经获取到相关的行政区划。", gin.H{"regions": regions})
}

func fetchAllLeveledRegions(c *gin.Context) {
	result := response.NewResult(c)
	requestRegionCode := c.Param("rid")
	regions, err := service.RegionService.FetchAllParentRegions(requestRegionCode)
	if err != nil {
		result.Error(http.StatusInternalServerError, err.Error())
		return
	}
	if len(regions) == 0 {
		result.Json(http.StatusNotFound, "未能获取到相关的行政区划。", gin.H{"regions": make([]string, 0)})
		return
	}
	result.Json(http.StatusOK, "以及获取到相关的行政区划。", gin.H{"regions": regions})
}
